SWDEV-470698 - fix formatting, add format check workflow (#657)

Dieser Commit ist enthalten in:
Danylo Lytovchenko
2025-08-20 16:28:06 +02:00
committet von GitHub
Ursprung 5840940caa
Commit f7338717ae
1574 geänderte Dateien mit 162972 neuen und 199346 gelöschten Zeilen
@@ -17,17 +17,17 @@ OUT OF OR INN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.
*/
#include <hip_test_common.hh>
#include <new>
#include <new>
// Test __HIP_DEVICE_COMPILE__ is defined after math_functions.h
// is included.
__device__ __host__ inline void throw_std_bad_alloc() {
#ifndef __HIP_DEVICE_COMPILE__
throw std::bad_alloc();
#else
std::size_t kHuge = static_cast<std::size_t>(-1);
new int[kHuge];
#endif
#ifndef __HIP_DEVICE_COMPILE__
throw std::bad_alloc();
#else
std::size_t kHuge = static_cast<std::size_t>(-1);
new int[kHuge];
#endif
}
__global__ void FloatMathPreciseKernel() {
@@ -127,8 +127,7 @@ __global__ void FloatMathPreciseKernel() {
TEST_CASE("Unit_TestIncludeMathPreciseFloat") {
hipError_t err;
err = hipLaunchKernel(reinterpret_cast<void *>(FloatMathPreciseKernel),
dim3(1, 1, 1),
dim3(1, 1, 1), 0, 0, 0);
err = hipLaunchKernel(reinterpret_cast<void*>(FloatMathPreciseKernel), dim3(1, 1, 1),
dim3(1, 1, 1), 0, 0, 0);
REQUIRE(err == hipSuccess);
}